==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/CategoryHighlightLayerDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AnnotationLayerDescriptionMetadata } from "./AnnotationLayerDescriptionMetadata";
import { CategoryHighlightLayerDescription } from "./CategoryHighlightLayerDescription";
/**
 * @hidden
 */
export let CategoryHighlightLayerDescriptionMetadata = /*@__PURE__*/ (() => {
    class CategoryHighlightLayerDescriptionMetadata extends Base {
        static b(a) {
            if (CategoryHighlightLayerDescriptionMetadata.a == null) {
                CategoryHighlightLayerDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                CategoryHighlightLayerDescriptionMetadata.c(CategoryHighlightLayerDescriptionMetadata.a);
            }
            if (a.j(CategoryHighlightLayerDescriptionMetadata.a)) {
                return;
            }
            a.y(CategoryHighlightLayerDescriptionMetadata.a);
        }
        static c(a) {
            AnnotationLayerDescriptionMetadata.c(a);
            a.item("TargetAxisRef", "(w:TargetAxis,wf:TargetAxis)DataRef::object");
            a.item("UseInterpolation", "Boolean");
            a.item("BandHighlightWidth", "Number:double");
        }
        static d(a) {
            CategoryHighlightLayerDescriptionMetadata.b(a);
            a.aa("CategoryHighlightLayer", () => new CategoryHighlightLayerDescription());
            a.z("CategoryHighlightLayer", CategoryHighlightLayerDescriptionMetadata.a);
        }
    }
    CategoryHighlightLayerDescriptionMetadata.$t = /*@__PURE__*/ markType(CategoryHighlightLayerDescriptionMetadata, 'CategoryHighlightLayerDescriptionMetadata');
    CategoryHighlightLayerDescriptionMetadata.a = null;
    return CategoryHighlightLayerDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/CategoryHighlightLayerDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AnnotationLayerDescriptionMetadata } from "./AnnotationLayerDescriptionMetadata";
import { CategoryHighlightLayerDescription } from "./CategoryHighlightLayerDescription";
/**
 * @hidden
 */
export let CategoryHighlightLayerDescriptionMetadata = /*@__PURE__*/ (() => {
    class CategoryHighlightLayerDescriptionMetadata extends Base {
        static b(a) {
            if (CategoryHighlightLayerDescriptionMetadata.a == null) {
                CategoryHighlightLayerDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                CategoryHighlightLayerDescriptionMetadata.c(CategoryHighlightLayerDescriptionMetadata.a);
            }
            if (a.k(CategoryHighlightLayerDescriptionMetadata.a)) {
                return;
            }
            a.aa(CategoryHighlightLayerDescriptionMetadata.a);
        }
        static c(a) {
            AnnotationLayerDescriptionMetadata.c(a);
            a.item("TargetAxisRef", "(w:TargetAxis,wf:TargetAxis)DataRef::object");
            a.item("UseInterpolation", "Boolean");
            a.item("BandHighlightWidth", "Number:double");
        }
        static d(a) {
            CategoryHighlightLayerDescriptionMetadata.b(a);
            a.ac("CategoryHighlightLayer", () => new CategoryHighlightLayerDescription());
            a.ab("CategoryHighlightLayer", CategoryHighlightLayerDescriptionMetadata.a);
        }
    }
    CategoryHighlightLayerDescriptionMetadata.$t = /*@__PURE__*/ markType(CategoryHighlightLayerDescriptionMetadata, 'CategoryHighlightLayerDescriptionMetadata');
    CategoryHighlightLayerDescriptionMetadata.a = null;
    return CategoryHighlightLayerDescriptionMetadata;
})();
